@@ -238,7 +238,7 @@
 ; euler constant "#2107"
 ; scruple	"#2108"
 ; degree fahrenheit "#2109"
-; <cal-g>	"#210A"
+("<cal-g>"	"#210A")
 ("<cal-H>"	"#210B")
 ("<frak-H>"	"#210C")
 ("<bbb-H>"	"#210D")
@@ -275,12 +275,12 @@
 ("<cal-B>"	"#212C")
 ("<frak-C>"	"#212D")
 ; estimated symbol "#212E"
-; <cal-e>	"#212F"
+("<cal-e>"	"#212F")
 ("<cal-E>"	"#2130")
 ("<cal-F>"	"#2131")
 ; turned capital f "#2132"
 ("<cal-M>"	"#2133")
-; <cal-o>	"#2134"
+("<cal-o>"	"#2134")
 
 ;; Hebrew letterlike math symbols
 ("<aleph>"	"#2135")
@@ -1265,34 +1265,32 @@
 ("<cal-X>"	"#1D4B3")
 ("<cal-Y>"	"#1D4B4")
 ("<cal-Z>"	"#1D4B5")
-
-;; TeXmacs has no lowercase script symbol
-;("<cal-a>"	"#1D4B6")
-;("<cal-b>"	"#1D4B7")
-;("<cal-c>"	"#1D4B8")
-;("<cal-d>"	"#1D4B9")
-;;("<cal-e>"	"#212F")
-;("<cal-f>"	"#1D4BB")
-;;("<cal-g>"	"#210A")
-;("<cal-h>"	"#1D4BD")
-;("<cal-i>"	"#1D4BE")
-;("<cal-j>"	"#1D4BF")
-;("<cal-k>"	"#1D4C0")
-;("<cal-l>"	"#1D4C1")
-;("<cal-m>"	"#1D4C2")
-;("<cal-n>"	"#1D4C3")
-;;("<cal-o>"	"#2134")
-;("<cal-p>"	"#1D4C5")
-;("<cal-q>"	"#1D4C6")
-;("<cal-r>"	"#1D4C7")
-;("<cal-s>"	"#1D4C8")
-;("<cal-t>"	"#1D4C9")
-;("<cal-u>"	"#1D4CA")
-;("<cal-v>"	"#1D4CB")
-;("<cal-w>"	"#1D4CC")
-;("<cal-x>"	"#1D4CD")
-;("<cal-y>"	"#1D4CE")
-;("<cal-z>"	"#1D4CF")
+("<cal-a>"	"#1D4B6")
+("<cal-b>"	"#1D4B7")
+("<cal-c>"	"#1D4B8")
+("<cal-d>"	"#1D4B9")
+;("<cal-e>"	"#212F")
+("<cal-f>"	"#1D4BB")
+;("<cal-g>"	"#210A")
+("<cal-h>"	"#1D4BD")
+("<cal-i>"	"#1D4BE")
+("<cal-j>"	"#1D4BF")
+("<cal-k>"	"#1D4C0")
+("<cal-l>"	"#1D4C1")
+("<cal-m>"	"#1D4C2")
+("<cal-n>"	"#1D4C3")
+;("<cal-o>"	"#2134")
+("<cal-p>"	"#1D4C5")
+("<cal-q>"	"#1D4C6")
+("<cal-r>"	"#1D4C7")
+("<cal-s>"	"#1D4C8")
+("<cal-t>"	"#1D4C9")
+("<cal-u>"	"#1D4CA")
+("<cal-v>"	"#1D4CB")
+("<cal-w>"	"#1D4CC")
+("<cal-x>"	"#1D4CD")
+("<cal-y>"	"#1D4CE")
+("<cal-z>"	"#1D4CF")
 
 ;; Bold script symbols
 ("<b-cal-A>"	"#1D4D0")
@@ -1321,34 +1319,32 @@
 ("<b-cal-X>"	"#1D4E7")
 ("<b-cal-Y>"	"#1D4E8")
 ("<b-cal-Z>"	"#1D4E9")
-
-;; TeXmacs has no lowercase script symbol
-;("<b-cal-a>"	"#1D4EA")
-;("<b-cal-b>"	"#1D4EB")
-;("<b-cal-c>"	"#1D4EC")
-;("<b-cal-d>"	"#1D4ED")
-;("<b-cal-e>"	"#1D4EE")
-;("<b-cal-f>"	"#1D4EF")
-;("<b-cal-g>"	"#1D4F0")
-;("<b-cal-h>"	"#1D4F1")
-;("<b-cal-i>"	"#1D4F2")
-;("<b-cal-j>"	"#1D4F3")
-;("<b-cal-k>"	"#1D4F4")
-;("<b-cal-l>"	"#1D4F5")
-;("<b-cal-m>"	"#1D4F6")
-;("<b-cal-n>"	"#1D4F7")
-;("<b-cal-o>"	"#1D4F8")
-;("<b-cal-p>"	"#1D4F9")
-;("<b-cal-q>"	"#1D4FA")
-;("<b-cal-r>"	"#1D4FB")
-;("<b-cal-s>"	"#1D4FC")
-;("<b-cal-t>"	"#1D4FD")
-;("<b-cal-u>"	"#1D4FE")
-;("<b-cal-v>"	"#1D4FF")
-;("<b-cal-w>"	"#1D500")
-;("<b-cal-x>"	"#1D501")
-;("<b-cal-y>"	"#1D502")
-;("<b-cal-z>"	"#1D503")
+("<b-cal-a>"	"#1D4EA")
+("<b-cal-b>"	"#1D4EB")
+("<b-cal-c>"	"#1D4EC")
+("<b-cal-d>"	"#1D4ED")
+("<b-cal-e>"	"#1D4EE")
+("<b-cal-f>"	"#1D4EF")
+("<b-cal-g>"	"#1D4F0")
+("<b-cal-h>"	"#1D4F1")
+("<b-cal-i>"	"#1D4F2")
+("<b-cal-j>"	"#1D4F3")
+("<b-cal-k>"	"#1D4F4")
+("<b-cal-l>"	"#1D4F5")
+("<b-cal-m>"	"#1D4F6")
+("<b-cal-n>"	"#1D4F7")
+("<b-cal-o>"	"#1D4F8")
+("<b-cal-p>"	"#1D4F9")
+("<b-cal-q>"	"#1D4FA")
+("<b-cal-r>"	"#1D4FB")
+("<b-cal-s>"	"#1D4FC")
+("<b-cal-t>"	"#1D4FD")
+("<b-cal-u>"	"#1D4FE")
+("<b-cal-v>"	"#1D4FF")
+("<b-cal-w>"	"#1D500")
+("<b-cal-x>"	"#1D501")
+("<b-cal-y>"	"#1D502")
+("<b-cal-z>"	"#1D503")
 
 ;; Fraktur symbols
 ("<frak-A>"	"#1D504")
