@@ -1,4 +1,4 @@
-<TeXmacs|1.0.7.9>
+<TeXmacs|1.0.7.12>
 
 <style|<tuple|source|std>>
 
@@ -211,6 +211,10 @@
 
   <assign|center|<macro|body|<with|par-mode|center|<arg|body>>>>
 
+  <assign|left-aligned|<macro|body|<with|par-mode|left|<arg|body>>>>
+
+  <assign|right-aligned|<macro|body|<with|par-mode|right|<arg|body>>>>
+
   <assign|quote-env|<\macro|body>
     <\padded>
       <\indent-both|3fn|3fn>
@@ -262,6 +266,16 @@
     </src-comment>
   </active*>
 
+  <assign|with-opacity|<macro|fact|body|<with|opacity|<times|<arg|fact>|<value|opacity>>|<arg|body>>>>
+
+  <assign|pastel|<macro|body|<with-opacity|0.1|<arg|body>>>>
+
+  <assign|greyed|<macro|body|<with-opacity|0.33333|<arg|body>>>>
+
+  <assign|light|<macro|body|<with-opacity|0.5|<arg|body>>>>
+
+  \;
+
   <assign|hresize|<macro|body|left|right|<resize|<arg|body>|<arg|left>||<arg|right>|>>>
 
   <assign|hextend|<macro|body|right|<resize|<arg|body>|||<maximum|1r|<arg|right>>|>>>
@@ -298,6 +312,8 @@
 
   <assign|frame|<macro|body|<block|<tformat|<table|<row|<cell|<arg|body>>>>>>>>
 
+  <assign|colored-frame|<macro|col|body|<block|<tformat|<cwith|1|1|1|1|cell-background|<arg|col>>|<table|<row|<cell|<arg|body>>>>>>>>
+
   <assign|overline|<macro|body|<eval|<quasiquote|<style-with|src-compact|none|<datoms|<macro|body|<with|color|<unquote|<value|color>>|<wide|<arg|body>|\<wide-bar\>>>>|<arg|body>>>>>>>
 
   <drd-props|overline|with-like|yes|arity|1|accessible|all>
@@ -306,15 +322,35 @@
 
   <drd-props|underline|with-like|yes|arity|1|accessible|all>
 
-  \;
+  <\active*>
+    <\src-comment>
+      Tags for HTML generation.
+    </src-comment>
+  </active*>
+
+  <assign|html-div|<macro|name|body|<arg|body>>>
+
+  <assign|html-style|<macro|style|body|<arg|body>>>
+
+  <assign|html-javascript|<macro|script|<small|<colored-frame|pastel
+  yellow|<with|font-family|ss|Javascript:
+  ><with|font-family|tt|<arg|script>>>>>>
+
+  <assign|html-javascript-src|<macro|source-file|<small|<colored-frame|pastel
+  yellow|<with|font-family|ss|Javascript source:
+  ><href|<arg|source-file>>>>>>
+
+  <\active*>
+    <\src-comment>
+      Miscellaneous.
+    </src-comment>
+  </active*>
 
   <assign|href|<macro|body|<hlink|<with|font-family|tt|<arg|body>>|<arg|body>>>>
 
   <assign|slink|<macro|body|<hlink|<with|font-family|tt|<arg|body>>|<arg|body>>>>
 
   <assign|square|<macro|x|<times|<arg|x>|<arg|x>>>>
-
-  \;
 </body>
 
 <\initial>
