@@ -42,17 +42,19 @@
   hline
   ;; rewritten
   notin vert Vert addots
+  implies iff gets
   ;; wikipedia
   infin rang)
 
 (drd-group latex-command-1%
   usepackage part part* chapter chapter*
   section section* subsection subsection* subsubsection subsubsection*
-  paragraph paragraph* subparagraph subparagraph*
+  paragraph paragraph* subparagraph subparagraph* nextbib
   footnote overline underline <sub> <sup> not left right
   big Big bigg Bigg bigl Bigl biggl Biggl
   bigm Bigm biggm Biggm bigr Bigr biggr Biggr
-  bar hat tilde widehat widetilde vec grave acute check breve abovering
+  bar hat tilde widehat widetilde vec
+  grave acute check breve abovering mathring
   dot ddot dddot ddddot
   label ref pageref index hspace hspace* vspace vspace*
   mbox hbox text not substack
@@ -66,7 +68,7 @@
   newcounter stepcounter refstepcounter value
   citet citep citet* citep* citealt citealp citealt* citealp*
   citetext citeauthor citeauthor* citeyear
-  epsfig url penalty centerline fbox
+  epsfig url penalty centerline fbox framebox
   enlargethispage)
 
 (drd-group latex-command-1% ;; . needs a special treatment
@@ -100,7 +102,8 @@
 
 (drd-group latex-command-1*%
   documentclass documentstyle sqrt bibitem cite
-  includegraphics includegraphics*)
+  includegraphics includegraphics*
+  subjclass)
 
 (drd-group latex-command-2*%
   def newcommand renewcommand newtheorem newtheorem* frac parbox)
@@ -126,7 +129,8 @@
   begin-document begin-abstract begin-verbatim begin-proof
   begin-matrix begin-pmatrix begin-bmatrix begin-vmatrix begin-smallmatrix
   begin-cases
-  begin-center begin-picture)
+  begin-center begin-flushleft begin-flushright
+  begin-picture)
 
 (drd-group latex-environment-0*%
   begin-figure begin-table)
@@ -186,7 +190,9 @@
   inf ker lg lim liminf limsup ln log max min Pr sec sin sinh sup tan tanh)
 
 (drd-group latex-list%
-  begin-itemize begin-enumerate begin-description begin-inparaenum)
+  begin-itemize begin-enumerate begin-description
+  begin-asparaitem begin-inparaitem begin-compactitem
+  begin-asparaenum begin-inparaenum begin-compactenum)
 
 (drd-group latex-math-environment-0%
   begin-formula begin-equation*
