@@ -14,7 +14,8 @@
 (texmacs-module (dynamic fold-edit)
   (:use (utils library tree)
 	(utils library cursor)
-	(dynamic dynamic-drd)))
+	(dynamic dynamic-drd)
+	(generic generic-edit)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Dynamic movements for fold tags and switches
@@ -142,23 +143,23 @@
   (and t i (>= i 0) (< i (tree-arity t))))
 
 (tm-define (switch-index t . args)
-  (when (switch-context? t)
-    (and-let* ((i (if (null? args) :current (car args)))
-               (c (tree-down-index t))
-               (l (- (tree-arity t) 1))
-               (v (switch-last-visible t)))
-      (cond ((< v 0) #f)
-            ((== i :visible) v)
-            ((== i :current) c)
-            ((== i :previous) (max 0 (- c 1)))
-            ((== i :next) (min l (+ c 1)))
-            ((== i :var-previous) (- c 1))
-            ((== i :var-next) (+ c 1))
-            ((== i :rotate-backward) (if (= c 0) l (- c 1)))
-            ((== i :rotate-forward) (if (= c l) 0 (+ c 1)))
-            ((== i :first) 0)
-            ((== i :last) l)
-            (else i)))))
+  (and-let* ((o (switch-context? t))
+             (i (if (null? args) :current (car args)))
+             (c (tree-down-index t))
+             (l (- (tree-arity t) 1))
+             (v (switch-last-visible t)))
+    (cond ((< v 0) #f)
+          ((== i :visible) v)
+          ((== i :current) c)
+          ((== i :previous) (max 0 (- c 1)))
+          ((== i :next) (min l (+ c 1)))
+          ((== i :var-previous) (- c 1))
+          ((== i :var-next) (+ c 1))
+          ((== i :rotate-backward) (if (= c 0) l (- c 1)))
+          ((== i :rotate-forward) (if (= c l) 0 (+ c 1)))
+          ((== i :first) 0)
+          ((== i :last) l)
+          (else i))))
 
 (tm-define (switch-to t i . args)
   (set! i (switch-index t i))
@@ -185,10 +186,10 @@
            (l (- (tree-arity t) 2)))
       (switch-set-range t (max 0 (- i 1)) (min l (+ i 1)) #t)
       (tree-remove! t i 1)
-      (tree-go-to t (min i l) :start)
       (if (tree-in? t (alternative-tag-list))
           (switch-select t (min i l))
-          (switch-select t (max 0 (- v 1)))))))
+          (switch-select t (max 0 (- v 1))))
+      (tree-go-to t (min i l) :start))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Specific types of switches
@@ -251,7 +252,7 @@
   (with i (if forwards? :current :var-previous)
     (set! i (switch-index t i))
     (cond ((< i 0) (tree-go-to t :start))
-          ((and forwards? (= i (- (tree-arity t) 1))) (tree-go-to t :end))
+          ((>= i (tree-arity t)) (tree-go-to t :end))
           (else (switch-remove-at t i)))))
 
 (tm-define (structured-remove-vertical t downwards?)
