@@ -33,35 +33,25 @@
 (tm-define Mod4Mask    16384)
 (tm-define Mod5Mask    32768)
 
-(tm-define (kbd-tab)
-  (:mode in-graphics?)
-  (graphics-choose-point))
+(tm-define (kbd-variant t forwards?)
+  (:require (in-active-graphics?))
+  (graphics-choose-point (if forwards? 1 -1)))
 
-(tm-define (kbd-left)
-  (:inside text-at)
-  (go-to-remain-inside go-left 'text-at))
+(tm-define (kbd-horizontal t forwards?)
+  (:require (tree-is? t 'text-at))
+  (with move (if forwards? go-right go-left)
+    (go-to-remain-inside move 'text-at)))
 
-(tm-define (kbd-right)
-  (:inside text-at)
-  (go-to-remain-inside go-right 'text-at))
+(tm-define (kbd-vertical t downwards?)
+  (:require (tree-is? t 'text-at))
+  (with move (if downwards? go-down go-up)
+    (go-to-remain-inside move 'text-at)))
 
-(tm-define (kbd-up)
-  (:inside text-at)
-  (go-to-remain-inside go-up 'text-at))
-
-(tm-define (kbd-down)
-  (:inside text-at)
-  (go-to-remain-inside go-down 'text-at))
-
-(tm-define (kbd-start-line)
-  (:inside text-at)
-  (with move (lambda () (go-to-remain-inside go-left 'text-at))
-    (go-to-repeat move)))
-
-(tm-define (kbd-end-line)
-  (:inside text-at)
-  (with move (lambda () (go-to-remain-inside go-right 'text-at))
-    (go-to-repeat move)))
+(tm-define (kbd-extremal t forwards?)
+  (:require (tree-is? t 'text-at))
+  (with move (if forwards? go-right go-left)
+    (with action (lambda () (go-to-remain-inside move 'text-at))
+      (go-to-repeat action))))
 
 (define (in-active-graphics?)
   (and (in-graphics?) (== (get-env "preamble") "false")))
@@ -108,8 +98,8 @@
   ("M-up"    (if (current-is-textat?)
 		 (text-at-change-valign current-path #t)
 		 (graphics-change-geo-valign #t)))
-  ("backspace" (graphics-kbd-remove #f))
-  ("delete" (graphics-kbd-remove #t))
+  ("backspace" (graphics-kbd-backspace))
+  ("delete" (graphics-kbd-delete))
   ("C-g" (graphics-toggle-grid #f))
   ("C-G" (graphics-toggle-grid #t)))
 
