@@ -344,9 +344,11 @@
 (tm-define (brackets-refresh)
   (insert-go-to '(temp-slot "") '(0 0))
   (let* ((t (find-non-bracket (cursor-tree)))
-	 (u (tree-downgrade-brackets t #t))
-	 (v (tree-upgrade-brackets u "math")))
-    (tree-set! t v)
+	 (u (tree-downgrade-brackets t #t #f))
+	 (v (tree-upgrade-brackets u "math"))
+         (w (tree-downgrade-big v)))
+    ;;(tree-set! t v)
+    (tree-set! t w)
     (find-and-remove-temp-slot t)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -419,6 +421,11 @@
 	      (set! ret t))))))
     ret))
 
+(define (at-end? t)
+  (with p (cursor-path)
+    (or (== p (tree->path t 1 :end))
+        (== p (tree->path t :end)))))
+
 (tm-define (math-bracket-open lb rb large?)
   (when (== large? 'default)
     (set! large? (!= (get-preference "use large brackets") "off")))
@@ -426,25 +433,33 @@
     (make-bracket-open lb rb large?)
     (brackets-refresh))
   (when (!= (get-preference "automatic brackets") "off")
-    (let* ((t (find-adjacent-around #t))
-	   (u (find-adjacent-around #f)))
-      (cond ((and t (deleted? t 0))
-	     (tree-set t 0 lb)
-	     (tree-go-to t 1 :start))
-	    ((and t (deleted? t 2))
-	     (tree-set t 2 lb)
-	     (tree-go-to t :end))
-	    ((and u (== lb rb) (== (tree->stree (tree-ref u 2)) rb))
-	     (tree-go-to u :end))
-	    ((and u (== (tree->stree (tree-ref u 0)) "<langle>") (== rb "|"))
-	     (tree-set u 2 rb)
-	     (tree-go-to u :end))
-	    ((try-matching-insert #t lb large?)
-	     (noop))
-	    ((not large?)
-	     (insert-go-to `(around ,lb "" ,rb) '(1 0)))
-	    (large?
-	     (insert-go-to `(around* ,lb "" ,rb) '(1 0)))))))
+    (if (selection-active-normal?)
+	(begin
+	  (clipboard-cut "temp")
+          (insert-go-to `(,(if large? 'around* 'around) ,lb "" ,rb) '(1 0))
+	  (clipboard-paste "temp"))
+        (let* ((t (find-adjacent-around #t))
+               (u (find-adjacent-around #f)))
+          (cond ((and t (deleted? t 2)
+                      (or (not (deleted? t 0))
+                          (at-end? t)))
+                 (tree-set t 2 lb)
+                 (tree-go-to t :end))
+                ((and t (deleted? t 0))
+                 (tree-set t 0 lb)
+                 (tree-go-to t 1 :start))
+                ((and u (== lb rb)
+                      (== (tree->stree (tree-ref u 2)) rb))
+                 (tree-go-to u :end))
+                ((and u (== rb "|")
+                      (== (tree->stree (tree-ref u 0)) "<langle>"))
+                 (tree-set u 2 rb)
+                 (tree-go-to u :end))
+                ((try-matching-insert #t lb large?)
+                 (noop))
+                (else
+                  (insert-go-to `(,(if large? 'around* 'around) ,lb "" ,rb)
+                                '(1 0))))))))
 
 (tm-define (math-separator sep large?)
   (when (== large? 'default)
@@ -466,7 +481,9 @@
   (when (!= (get-preference "automatic brackets") "off")
     (let* ((t (find-adjacent-around #t))
 	   (u (find-adjacent-around #f)))
-      (cond ((and t (deleted? t 0))
+      (cond ((and t (deleted? t 0)
+                  (or (not (deleted? t 2))
+                      (not (at-end? t))))
 	     (tree-set t 0 rb)
 	     (tree-go-to t 1 :start))
 	    ((and t (deleted? t 2))
@@ -482,11 +499,12 @@
 			   (force-string rb)))))))
 
 (tm-define (math-big-operator op)
-  (when (== (get-preference "automatic brackets") "off")
-    (make-big-operator op)
-    (brackets-refresh))
-  (when (!= (get-preference "automatic brackets") "off")
-    (insert-go-to `(big-around ,(make-small op) "") '(1 0))))
+  ;;(when (== (get-preference "automatic brackets") "off")
+  ;;  (make-big-operator op)
+  ;;  (brackets-refresh))
+  ;;(when (!= (get-preference "automatic brackets") "off")
+  ;;  (insert-go-to `(big-around ,(make-small op) "") '(1 0)))
+  (insert `(big ,op)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Correction of mathematical formulas
