@@ -146,6 +146,16 @@
 (define (table-set-format-list vars vals)
   (map table-set-format vars vals))
 
+(tm-define (table-set-rows nr)
+  (:synopsis "Set the number of rows of the table to @nr.")
+  (:argument nr "Number of rows")
+  (table-set-extents (string->number nr) (table-nr-columns)))
+
+(tm-define (table-set-columns nr)
+  (:synopsis "Set the number of columns of the table to @nr.")
+  (:argument nr "Number of columns")
+  (table-set-extents (table-nr-rows) (string->number nr)))
+
 (define (table-get-width) (table-get-format "table-width"))
 (define (table-get-hmode) (table-get-format "table-hmode"))
 
@@ -195,6 +205,16 @@
   (:check-mark "o" table-test-maximal-width?)
   (interactive table-set-maximal-width))
 
+(tm-define (table-test-parwidth?)
+  (== (table-get-width) "1par"))
+(tm-define (table-toggle-parwidth)
+  (:check-mark "o" table-test-parwidth?)
+  (if (table-test-parwidth?)
+      (table-set-format-list '("table-width" "table-hmode")
+                             '("" ""))
+      (table-set-format-list '("table-width" "table-hmode")
+                             '("1par" "exact"))))
+
 (define (table-get-height) (table-get-format "table-height"))
 (define (table-get-vmode) (table-get-format "table-vmode"))
 
@@ -262,6 +282,14 @@
   (:check-mark "*" table-test-halign?)
   (table-set-format "table-halign" s))
 
+(define (table-test-specific-halign? . l) (== (table-get-halign) "O"))
+(tm-define (table-specific-halign col)
+  (:synopsis "Align horizontally at the baseline of a specific column.")
+  (:check-mark "*" table-test-specific-halign?)
+  (:argument col "Align at column")
+  (table-set-format "table-col-origin" col)
+  (table-set-format "table-halign" "O"))
+
 (define (table-get-valign) (table-get-format "table-valign"))
 (define (table-test-valign? s) (== (table-get-valign) s))
 (tm-define (table-set-valign s)
@@ -269,6 +297,14 @@
   (:check-mark "*" table-test-valign?)
   (table-set-format "table-valign" s))
 
+(define (table-test-specific-valign? . l) (== (table-get-valign) "O"))
+(tm-define (table-specific-valign row)
+  (:synopsis "Align vertically at the baseline of a specific row.")
+  (:check-mark "*" table-test-specific-valign?)
+  (:argument row "Align at row")
+  (table-set-format "table-row-origin" row)
+  (table-set-format "table-valign" "O"))
+
 (define (table-hyphen?) (== "y" (table-get-format "table-hyphen")))
 (define (table-set-hyphen s) (table-set-format "table-hyphen" s))
 (tm-define (toggle-table-hyphen)
@@ -450,6 +486,14 @@
   (:argument cs "Column span")
   (cell-set-format-list '("cell-row-span" "cell-col-span") (list rs cs)))
 
+(tm-define (cell-set-row-span rs)
+  (:argument rs "Row span")
+  (cell-set-format "cell-row-span" rs))
+
+(tm-define (cell-set-column-span cs)
+  (:argument cs "Column span")
+  (cell-set-format "cell-col-span" cs))
+
 (define (cell-get-halign) (cell-get-format "cell-halign"))
 (define (cell-test-halign? s) (== (cell-get-halign) s))
 (tm-define (cell-set-halign s)
@@ -482,10 +526,18 @@
 (define (cell-get-hyphen) (cell-get-format "cell-hyphen"))
 (define (cell-test-hyphen? s) (== (cell-get-hyphen) s))
 (tm-define (cell-set-hyphen s)
-  (:synopsis "Set hyphenation mode for cell.")
+  (:synopsis "Set cell wrapping mode.")
   (:check-mark "o" cell-test-hyphen?)
   (cell-set-format "cell-hyphen" s))
 
+(tm-define (cell-test-wrap?) (!= (cell-get-hyphen) "n"))
+(tm-define (cell-toggle-wrap)
+  (:synopsis "Toggle cell wrapping mode.")
+  (:check-mark "o" cell-test-wrap?)
+  (if (cell-test-wrap?)
+      (cell-set-format "cell-hyphen" "n")
+      (cell-set-format "cell-hyphen" "t")))
+
 (define (cell-get-block) (cell-get-format "cell-block"))
 (define (cell-test-block? s) (== (cell-get-block) s))
 (tm-define (cell-set-block s)
