@@ -47,45 +47,44 @@
 	      ("Palatino" (make-with "font" "palatino")))
 	  (if (url-exists-in-tex? "rptmr.tfm")
 	      ("Times" (make-with "font" "times"))))
-      (if (> (get-font-type) 0)
-	  (if (or (font-exists-in-tt? "luxirr")
-		  (font-exists-in-tt? "Apple Symbols")
-		  (font-exists-in-tt? "STIXGeneral"))
-	      (-> "True type"
-		  (if (font-exists-in-tt? "DejaVuSerif")
-		      ("Dejavu" (make-with "font" "dejavu")))
-		  (if (font-exists-in-tt? "LucidaGrande")
-		      ("Lucida Grande" (make-with "font" "apple-lucida")))
-		  (if (font-exists-in-tt? "luxirr")
-		      ("Luxi" (make-with "font" "luxi")))
-		  (if (font-exists-in-tt? "STIXGeneral")
-		      ("Stix" (make-with "font" "stix")))
-		  (if (font-exists-in-tt? "Apple Symbols")
-		      ("Symbols" (make-with "font" "apple-symbols")))))
-	  (if (font-exists-in-tt? "times")
-	      (-> "Microsoft"
-		  (if (font-exists-in-tt? "andalemo")
-		      ("Andalemo" (make-with "font" "ms-andalemo")))
-		  (if (font-exists-in-tt? "arial")
-		      ("Arial" (make-with "font" "ms-arial")))
-		  (if (font-exists-in-tt? "comic")
-		      ("Comic" (make-with "font" "ms-comic")))
-		  (if (font-exists-in-tt? "cour")
-		      ("Courier" (make-with "font" "ms-courier")))
-		  (if (font-exists-in-tt? "georgia")
-		      ("Georgia" (make-with "font" "ms-georgia")))
-		  (if (font-exists-in-tt? "impact")
-		      ("Impact" (make-with "font" "ms-impact")))
-		  (if (font-exists-in-tt? "lucon")
-		      ("Lucida" (make-with "font" "ms-lucida")))
-		  (if (font-exists-in-tt? "tahoma")
-		      ("Tahoma" (make-with "font" "ms-tahoma")))
-		  (if (font-exists-in-tt? "times")
-		      ("Times" (make-with "font" "ms-times")))
-		  (if (font-exists-in-tt? "trebuc")
-		      ("Trebuchet" (make-with "font" "ms-trebuchet")))
-		  (if (font-exists-in-tt? "verdana")
-		      ("Verdana" (make-with "font" "ms-verdana"))))))
+      (if (or (font-exists-in-tt? "luxirr")
+              (font-exists-in-tt? "Apple Symbols")
+              (font-exists-in-tt? "STIXGeneral"))
+          (-> "True type"
+              (if (font-exists-in-tt? "DejaVuSerif")
+                  ("Dejavu" (make-with "font" "dejavu")))
+              (if (font-exists-in-tt? "LucidaGrande")
+                  ("Lucida Grande" (make-with "font" "apple-lucida")))
+              (if (font-exists-in-tt? "luxirr")
+                  ("Luxi" (make-with "font" "luxi")))
+              (if (font-exists-in-tt? "STIXGeneral")
+                  ("Stix" (make-with "font" "stix")))
+              (if (font-exists-in-tt? "Apple Symbols")
+                  ("Symbols" (make-with "font" "apple-symbols")))))
+      (if (font-exists-in-tt? "times")
+          (-> "Microsoft"
+              (if (font-exists-in-tt? "andalemo")
+                  ("Andalemo" (make-with "font" "ms-andalemo")))
+              (if (font-exists-in-tt? "arial")
+                  ("Arial" (make-with "font" "ms-arial")))
+              (if (font-exists-in-tt? "comic")
+                  ("Comic" (make-with "font" "ms-comic")))
+              (if (font-exists-in-tt? "cour")
+                  ("Courier" (make-with "font" "ms-courier")))
+              (if (font-exists-in-tt? "georgia")
+                  ("Georgia" (make-with "font" "ms-georgia")))
+              (if (font-exists-in-tt? "impact")
+                  ("Impact" (make-with "font" "ms-impact")))
+              (if (font-exists-in-tt? "lucon")
+                  ("Lucida" (make-with "font" "ms-lucida")))
+              (if (font-exists-in-tt? "tahoma")
+                  ("Tahoma" (make-with "font" "ms-tahoma")))
+              (if (font-exists-in-tt? "times")
+                  ("Times" (make-with "font" "ms-times")))
+              (if (font-exists-in-tt? "trebuc")
+                  ("Trebuchet" (make-with "font" "ms-trebuchet")))
+              (if (font-exists-in-tt? "verdana")
+                  ("Verdana" (make-with "font" "ms-verdana")))))
       (-> "Latin"
 	  (if (url-exists-in-tex? "callig15.mf")
 	      ("Calligraphic" (make-with "font" "calligraphic")))
@@ -355,10 +354,12 @@
 
 (menu-bind paragraph-menu
   (-> "Alignment"
-      ("Justified" (make-line-with "par-mode" "justify"))
       ("Left ragged" (make-line-with "par-mode" "left"))
       ("Centered" (make-line-with "par-mode" "center"))
-      ("Right ragged" (make-line-with "par-mode" "right")))
+      ("Right ragged" (make-line-with "par-mode" "right"))
+      ---
+      ("Justified" (make-line-with "par-mode" "justify"))
+      ("Flexibility" (make-interactive-line-with "par-flexibility")))
   (-> "Margins"
       ("Left margin" (make-interactive-line-with "par-left"))
       ("Right margin" (make-interactive-line-with "par-right"))
@@ -407,6 +408,8 @@
       ---
       (group "Text")
       (-> "Color" (link color-menu))
+      (if (== (get-preference "experimental alpha") "on")
+          (-> "Opacity" (link opacity-menu)))
       (-> "Language" (link text-language-menu))
       (-> "Scripts" (link local-supported-scripts-menu))
       (-> "Space" (link horizontal-space-menu))
