@@ -116,7 +116,7 @@
 ;; Textual markup tags
 
 (define-group textual-tag
-  (strong-tag) (name-tag) (monospaced-tag))
+  (strong-tag) (name-tag) (monospaced-tag) (size-tag) (opacity-tag))
 
 (define-group strong-tag
   strong em dfn underline)
@@ -127,6 +127,13 @@
 (define-group monospaced-tag
   kbd code* var)
 
+(define-group size-tag
+  really-tiny tiny very-small small
+  normal-size large very-large huge really-huge)
+
+(define-group opacity-tag
+  pastel greyed light)
+
 ;; Figures and tables
 
 (define-group figure-tag
