@@ -5,17 +5,15 @@
 ;; DESCRIPTION : Initialize reduce plugin
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven and Andrey Grozin
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(lazy-menu (reduce-menus) reduce-help-menu)
-
 (define (reduce-initialize)
   (import-from (utils plugins plugin-convert))
+  (import-from (reduce-menus))
   (lazy-input-converter (reduce-input) reduce)
   (menu-extend session-help-icons
     (if (and (in-reduce?) (url-exists? "$reduce/doc/manual/abstract.tex"))
