@@ -86,6 +86,8 @@ filter_preamble (tree t) {
       title_info << u;
     else if (is_tuple (u, "\\subjclass"))
       title_info << u;
+    else if (is_tuple (u, "\\subjclass*"))
+      title_info << u;
     else if (in_preamble) {
       if (u == tuple ("\\begin-document")) {
 	r << u;
@@ -212,6 +214,9 @@ latex_symbol_to_tree (string s) {
       if (s == "\\lVert") return "<||>";
       if (s == "\\rVert") return "<||>";
       if (s == "\\qed") return compound ("math", "<Box>");
+      if (s == "\\implies") return "<Longrightarrow>";
+      if (s == "\\iff") return "<Longleftrightarrow>";
+      if (s == "\\gets") return "<leftarrow>";
     }
 
     if (latex_type (s) == "texmacs") {
@@ -685,6 +690,10 @@ latex_command_to_tree (tree t) {
   if (is_tuple (t, "\\<sub>", 1)) return tree (RSUB, l2e (t[1]));
   if (is_tuple (t, "\\not", 1)) return tree (NEG, l2e (t[1]));
   if (is_tuple (t, "\\bar", 1)) return tree (WIDE, l2e (t[1]), "<bar>");
+  if (is_tuple (t, "\\overline", 1))
+    return tree (WIDE, l2e (t[1]), "<bar>");
+  if (is_tuple (t, "\\underline", 1))
+    return tree (VAR_WIDE, l2e (t[1]), "<bar>");
   if (is_tuple (t, "\\hat", 1)) return tree (WIDE, l2e (t[1]), "^");
   if (is_tuple (t, "\\tilde", 1)) return tree (WIDE, l2e (t[1]), "~");
   if (is_tuple (t, "\\widehat", 1)) return tree (WIDE, l2e (t[1]), "^");
@@ -698,7 +707,7 @@ latex_command_to_tree (tree t) {
   if (is_tuple (t, "\\acute", 1)) return tree (WIDE, l2e (t[1]), "<acute>");
   if (is_tuple (t, "\\vec", 1)) return tree (WIDE, l2e (t[1]), "<vect>");
   if (is_tuple (t, "\\breve", 1)) return tree (WIDE, l2e (t[1]), "<breve>");
-  if (is_tuple (t, "\\abovering", 1))
+  if (is_tuple (t, "\\abovering", 1) || is_tuple (t, "\\mathring", 1))
     return tree (WIDE, l2e (t[1]), "<abovering>");
   if (is_tuple (t, "\\hspace", 1) || is_tuple (t, "\\hspace*", 1)) {
     tree r= t2e (t[1]);
@@ -775,7 +784,7 @@ latex_command_to_tree (tree t) {
     return latex_cite_to_tree (cite_type, s);
   }
   if (is_tuple (t, "\\cite*", 2)) {
-    tree   ot= t2e(t[1])->label;
+    tree   ot= l2e (t[1]);
     string s = v2e (t[2]);
     tree   ct= latex_cite_to_tree ("cite", s);
     if (N(ct) == 2) return compound ("cite-detail", ct[1], ot);
@@ -868,6 +877,7 @@ latex_command_to_tree (tree t) {
     }
   }
   if (is_tuple (t, "\\fbox", 1)) return compound ("frame", l2e (t[1]));
+  if (is_tuple (t, "\\framebox", 1)) return compound ("frame", l2e (t[1]));
   if (is_tuple (t, "\\centerline", 1)) return compound ("center", l2e (t[1]));
   if (is_tuple (t, "\\noalign", 1))
     return ""; // FIXME: for larger space in maple matrices
@@ -1202,10 +1212,20 @@ translate_list (string s) {
   if (s == "enumerateromancap") return "enumerate-romancap";
   if (s == "enumeratealpha") return "enumerate-alpha";
   if (s == "enumeratealphacap") return "enumerate-alphacap";
+  if (s == "asparaitem") return "itemize";
+  if (s == "inparaitem") return "itemize";
+  if (s == "compactitem") return "itemize";
+  if (s == "asparaenum") return "enumerate";
   if (s == "inparaenum") return "enumerate";
+  if (s == "compactenum") return "enumerate";
   if (s == "itemize*") return "itemize";
   if (s == "enumerate*") return "enumerate";
+  if (s == "asparaitem*") return "itemize";
+  if (s == "inparaitem*") return "itemize";
+  if (s == "compactitem*") return "itemize";
+  if (s == "asparaenum*") return "enumerate";
   if (s == "inparaenum*") return "enumerate";
+  if (s == "compactenum*") return "enumerate";
   return s;
 }
 
@@ -1645,6 +1665,37 @@ finalize_floats (tree t) {
   }
 }
 
+static bool
+is_hyper_link (string s) {
+  return starts (s, "http://") || starts (s, "ftp://");
+}
+
+tree
+finalize_misc (tree t) {
+  if (is_atomic (t)) return t;
+  else if (is_compound (t, "verbatim", 1) &&
+           is_atomic (t[0]) && is_hyper_link (t[0]->label)) {
+    return compound ("href", t[0]);
+  }
+  else if (is_func (t, WITH, 3) && t[0] == FONT_FAMILY && t[1] == "tt" &&
+           is_atomic (t[2]) && is_hyper_link (t[2]->label)) {
+    return compound ("href", t[2]);
+  }
+  else if (is_compound (t, "flushleft", 1) ||
+           is_compound (t, "leftaligned", 1))
+    return compound ("left-aligned", t[0]);
+  else if (is_compound (t, "flushright", 1) ||
+           is_compound (t, "rightaligned", 1))
+    return compound ("right-aligned", t[0]);
+  else {
+    int i, n= N(t);
+    tree r (t, n);
+    for (i=0; i<n; i++)
+      r[i]= finalize_misc (t[i]);
+    return r;
+  }
+}
+
 /******************************************************************************
 * Final changes programmed in Guile
 ******************************************************************************/
@@ -1672,9 +1723,9 @@ latex_to_tree (tree t1) {
   textm_unicode   = false;
   textm_natbib    = false;
   command_type ("!em") = "false";
-  // cout << "\n\nt1= " << t1 << "\n\n";
+  //cout << "\n\nt1= " << t1 << "\n\n";
   tree t2= is_document? filter_preamble (t1): t1;
-  // cout << "\n\nt2= " << t2 << "\n\n";
+  //cout << "\n\nt2= " << t2 << "\n\n";
   tree t3= parsed_latex_to_tree (t2);
   // cout << "\n\nt3= " << t3 << "\n\n";
   tree t4= finalize_document (t3);
@@ -1682,16 +1733,18 @@ latex_to_tree (tree t1) {
   tree t5= is_document? finalize_preamble (t4, style): t4;
   // cout << "\n\nt5= " << t5 << "\n\n";
   tree t6= handle_improper_matches (t5);
-  // cout << "\n\nt6= " << t6 << "\n\n";
+  //cout << "\n\nt6= " << t6 << "\n\n";
   if ((!is_document) && is_func (t6, DOCUMENT, 1)) t6= t6[0];
   tree t7= upgrade_tex (t6);
-  // cout << "\n\nt7= " << t7 << "\n\n";
+  //cout << "\n\nt7= " << t7 << "\n\n";
   tree t8= finalize_floats (t7);
   // cout << "\n\nt8= " << t8 << "\n\n";
-  tree t9= finalize_textm (t8);
+  tree t9= finalize_misc (t8);
   // cout << "\n\nt9= " << t9 << "\n\n";
-  tree t10= drd_correct (std_drd, t9);
+  tree t10= finalize_textm (t9);
   // cout << "\n\nt10= " << t10 << "\n\n";
+  tree t11= drd_correct (std_drd, t10);
+  // cout << "\n\nt11= " << t11 << "\n\n";
 
   if (!exists (url ("$TEXMACS_STYLE_PATH", style * ".ts")))
     style= "generic";
@@ -1710,15 +1763,15 @@ latex_to_tree (tree t1) {
     mods << tree (LANGUAGE) << tree (lan);
   }
 
-  tree t11= t10;
-  if (is_document) t11= simplify_correct (t10);
-  else if (N (mods) > 0) { t11= mods; t11 << t10; }
-  // cout << "\n\nt11= " << t11 << "\n\n";
-  tree t12= latex_correct (t11);
+  tree t12= t11;
+  if (is_document) t12= simplify_correct (t11);
+  else if (N (mods) > 0) { t12= mods; t12 << t11; }
   // cout << "\n\nt12= " << t12 << "\n\n";
+  tree t13= latex_correct (t12);
+  // cout << "\n\nt13= " << t13 << "\n\n";
 
   if (is_document) {
-    tree the_body   = compound ("body", t12);
+    tree the_body   = compound ("body", t13);
     tree the_style  = compound ("style", style);
     tree the_initial= compound ("initial", initial);
     if (textm_natbib)
@@ -1726,7 +1779,7 @@ latex_to_tree (tree t1) {
     if (N (initial) == 0) return tree (DOCUMENT, the_style, the_body);
     else return tree (DOCUMENT, the_style, the_body, the_initial);
   }
-  else return t12;
+  else return t13;
 }
 
 tree
