@@ -39,6 +39,7 @@ extern string FONT_SIZE;
 extern string FONT_BASE_SIZE;
 extern string MAGNIFICATION;
 extern string COLOR;
+extern string OPACITY;
 extern string BG_COLOR;
 extern string LOCUS_COLOR;
 extern string VISITED_COLOR;
@@ -70,6 +71,7 @@ extern string PROG_FONT_SHAPE;
 extern string PROG_SESSION;
 
 extern string PAR_MODE;
+extern string PAR_FLEXIBILITY;
 extern string PAR_HYPHEN;
 extern string PAR_WIDTH;
 extern string PAR_LEFT;
@@ -193,6 +195,7 @@ extern string TEXTAT_VALIGN;
 extern string GR_GEOMETRY;
 extern string GR_FRAME;
 extern string GR_MODE;
+extern string GR_OPACITY;
 extern string GR_COLOR;
 extern string GR_POINT_STYLE;
 extern string GR_LINE_WIDTH;
