@@ -94,17 +94,19 @@ edit_interface_rep::try_shortcut (string comb) {
     }
     else {
       if (sh_mark != 0 && !mark_cancel (sh_mark)) {
-	sh_mark= 0;
-	return false;
+        sh_mark= 0;
+        return false;
       }
     }
     sh_s= comb;
     sh_mark= new_marker ();
     mark_start (sh_mark);
+    archive_state ();
     string rew_s= sv->kbd_post_rewrite (sh_s);
     tree rew= sv->kbd_system_rewrite (rew_s);
     if (N(help)>0) set_message (help, rew);
     tree rhs= (shorth == rew_s? tree (""): sv->kbd_system_rewrite (shorth));
+    //cout << "Shortcut: " << sh_s << " -> " << rew << "\n";
     if ((search_forwards (" ", comb) >= 0 && comb != " ") ||
 	(search_forwards ("-", comb) >= 0 && comb != "-"))
       call ("set-temporary-message",
@@ -133,10 +135,21 @@ edit_interface_rep::key_press (string gkey) {
     interrupt_shortcut ();
     string s= key (9, N(key));
     if (s == "") return;
+    int i, n= N(s), pos= N(s);
+    for (i=0; i<n; i++)
+      if (s[i] == ':' && is_int (s (0, i))) {
+	int k= as_int (s (0, i));
+	s= s (i+1, n);
+	pos= 0;
+	for (int j=0; j<k && pos<N(s); j++)
+	  tm_char_forwards (s, pos);
+	break;
+      }
     pre_edit_s= s;
     pre_edit_mark= new_marker ();
     mark_start (pre_edit_mark);
-    insert_tree (compound ("pre-edit", s));
+    archive_state ();
+    insert_tree (compound ("pre-edit", s), path (0, pos));
     return;
   }
 
@@ -151,11 +164,14 @@ edit_interface_rep::key_press (string gkey) {
   if (N(rew) == 1) {
     int i ((unsigned char) rew[0]);
     if ((i >= 32 && i <= 127) || (i >= 128 && i <= 255))
-      if (!inside_active_graphics ())
+      if (!inside_active_graphics ()) {
+        archive_state ();
 	insert_tree (rew);
+      }
     interrupt_shortcut ();
   }
   else if (contains_unicode_char (rew)) {
+    archive_state ();
     insert_tree (key);
     interrupt_shortcut ();    
   }
