@@ -365,14 +365,15 @@ edit_select_rep::selection_active_normal () {
 }
 
 bool
-edit_select_rep::selection_active_table () {
+edit_select_rep::selection_active_table (bool strict) {
   if (!selection_active_any ()) return false;
   path p= common (start_p, end_p);
   if ((p == start_p) || (p == end_p)) p= path_up (p);
   tree t= subtree (et, p);
   return
     is_func (t, TFORMAT) || is_func (t, TABLE) ||
-    is_func (t, ROW) || is_func (t, CELL);
+    is_func (t, ROW) || is_func (t, CELL) ||
+    (!strict && N(t) == 1 && is_func (t[0], TFORMAT));
 }
 
 bool
@@ -461,14 +462,33 @@ path
 edit_select_rep::selection_get_subtable (
   int& row1, int& col1, int& row2, int& col2)
 {
-  path fp= ::table_search_format (et, common (start_p, end_p));
-  tree st= subtree (et, fp);
-  table_search_coordinates (st, tail (start_p, N(fp)), row1, col1);
-  table_search_coordinates (st, tail (end_p, N(fp)), row2, col2);
-  if (row1>row2) { int tmp= row1; row1= row2; row2= tmp; }
-  if (col1>col2) { int tmp= col1; col1= col2; col2= tmp; }
-  table_bound (fp, row1, col1, row2, col2);
-  return fp;
+  if (selection_active_table ()) {
+    path fp= ::table_search_format (et, common (start_p, end_p));
+    if (is_nil (fp)) return fp;
+    tree st= subtree (et, fp);
+    table_search_coordinates (st, tail (start_p, N(fp)), row1, col1);
+    table_search_coordinates (st, tail (end_p, N(fp)), row2, col2);
+    if (row1>row2) { int tmp= row1; row1= row2; row2= tmp; }
+    if (col1>col2) { int tmp= col1; col1= col2; col2= tmp; }
+    table_bound (fp, row1, col1, row2, col2);
+    return fp;
+  }
+  else if (selection_active_table (false)) {
+    path fp= ::table_search_format (et, common (start_p, end_p) * 0);
+    if (is_nil (fp)) return fp;
+    path p= fp;
+    tree st;
+    while (true) {
+      st= subtree (et, p);
+      if (is_func (st, TABLE) && N(st) > 0 && is_func (st[0], ROW)) break;
+      if (!is_func (st, TFORMAT)) return path ();
+      p= p * (N(st) - 1);
+    }
+    row1= 0; col1= 0;
+    row2= N(st)-1; col2= N(st[0])-1;
+    return fp;
+  }
+  else return path ();
 }
 
 void
@@ -551,6 +571,8 @@ path
 edit_select_rep::selection_get_path () {
   path start, end;
   selection_get (start, end);
+  if (end == start && end_p != start_p)
+    return path_up (start);
   return common (start, end);
 }
 
@@ -622,7 +644,7 @@ edit_select_rep::selection_set (string key, tree t, bool persistant) {
     if (selection_export == "html") t= exec_html (t, tp);
     if (selection_export == "latex") t= exec_latex (t, tp);
     if ((selection_export == "latex") && (mode == "math"))
-      t= tree (WITH, "mode", "math", t);
+      t= compound ("math", t);
     s= tree_to_generic (t, selection_export * "-snippet");
     s= selection_encode (lan, s);
   }
@@ -689,8 +711,14 @@ edit_select_rep::selection_paste (string key) {
     }
     else {
       if ((t[2] != mode) && (t[2] != "src") && (mode != "src") &&
-	  ((t[2] == "math") || (mode == "math")))
-	insert_tree (tree (WITH, copy (MODE), copy (t[2]), ""), path (2, 0));
+	  ((t[2] == "math") || (mode == "math"))) {
+        if (t[2] == "math")
+          insert_tree (compound ("math", ""), path (0, 0));
+        else if (t[2] == "text")
+          insert_tree (compound ("text", ""), path (0, 0));
+        else
+          insert_tree (tree (WITH, copy (MODE), copy (t[2]), ""), path (2, 0));
+      }
       if (is_func (t[1], TFORMAT) || is_func (t[1], TABLE)) {
 	int row, col;
 	path fp= search_format (row, col);
@@ -900,6 +928,7 @@ edit_select_rep::manual_focus_release () {
 
 path
 edit_select_rep::focus_search (path p, bool skip_flag, bool up_flag) {
+  //cout << "Search focus " << p << ", " << skip_flag << ", " << up_flag << "\n";
   if (!(rp < p)) return rp;
   tree st= subtree (et, p);
   if (!skip_flag) return p;
@@ -921,7 +950,7 @@ edit_select_rep::focus_search (path p, bool skip_flag, bool up_flag) {
 
 path
 edit_select_rep::focus_get (bool skip_flag) {
-  //cout << "Search focus " << focus_p << "\n";
+  //cout << "Search focus " << focus_p << ", " << skip_flag << "\n";
   if (!is_nil (focus_p))
     return focus_search (focus_p, skip_flag, false);
   if (selection_active_any ())
