@@ -31,12 +31,11 @@
   (tm-output tm_output (void string))
   (tm-errput tm_errput (void string))
   (win32-display win32_display (void string))
+  (cpp-error cpp_error (void))
   (scheme-dialect scheme_dialect (string))
   (get-texmacs-path get_texmacs_path (string))
   (plugin-list plugin_list (scheme_tree))
   (set-fast-environments set_fast_environments (void bool))
-  (get-font-type get_font_type (int))
-  (set-font-type set_font_type (void int))
   (font-exists-in-tt? tt_font_exists (bool string))
   (eval-system eval_system (string string))
   (var-eval-system var_eval_system (string string))
@@ -148,7 +147,9 @@
   (automatic-correct automatic_correct (tree content string))
   (manual-correct manual_correct (tree content))
   (tree-upgrade-brackets upgrade_brackets (tree content string))
-  (tree-downgrade-brackets downgrade_brackets (tree content bool))
+  (tree-upgrade-big upgrade_big (tree content))
+  (tree-downgrade-brackets downgrade_brackets (tree content bool bool))
+  (tree-downgrade-big downgrade_big (tree content))
   (math-status-print math_status_print (void))
   (math-status-reset math_status_reset (void))
 
