@@ -78,7 +78,8 @@ operator << (tm_ostream& out, observer o) {
 * 1) The "inserting modifications" (insert, split and insert_node) invoke
 *    the observers call-back routines after the actual modification and
 *    "assigning and deleting modifications" (assign, remove, join,
-*    assign_node and remove_node)  before the actual modification.
+*    assign_node and remove_node) before the actual modification.
+*    set_cursor does not make any modifications in the tree
 * 2) The split and join modifications pass the joined tree
 *    at position pos as an additional argument to the call-back routines.
 * 3) They also admit variant call back routines for the split/join nodes.
@@ -311,6 +312,20 @@ raw_remove_node (tree& ref, int pos) {
   // consistency_check ();
 }
 
+void
+raw_set_cursor (tree& ref, int pos, tree data) {
+  // cout << "Set cursor " << ref << " : " << pos << ", " << data << "\n";
+  modification mod= mod_set_cursor (path (), pos, data);
+  if (!is_nil (ref->obs)) {
+    ref->obs->announce (ref, mod);
+    ref->obs->notify_set_cursor (ref, pos, data);
+    simplify (ref->obs);
+  }
+  if (!is_nil (ref->obs)) ref->obs->done (ref, mod);
+  // stretched_print (ref, true, 1);
+  // consistency_check ();
+}
+
 void
 raw_apply (tree& t, modification mod) {
   ASSERT (is_applicable (t, mod), "invalid modification");
@@ -339,6 +354,9 @@ raw_apply (tree& t, modification mod) {
   case MOD_REMOVE_NODE:
     raw_remove_node (subtree (t, root (mod)), index (mod));
     break;
+  case MOD_SET_CURSOR:
+    raw_set_cursor (subtree (t, root (mod)), index (mod), mod->t);
+    break;
   }
   packrat_invalid_colors= true;
 }
@@ -368,7 +386,11 @@ busy_tree (tree& ref) {
 
 void
 apply (tree& ref, modification mod) {
-  ASSERT (is_applicable (ref, mod), "invalid modification");
+  if (!is_applicable (ref, mod)) {
+    cout << "mod= " << mod << "\n";
+    cout << "ref= " << ref << "\n";
+    ASSERT (is_applicable (ref, mod), "invalid modification");
+  }
   path ip= obtain_ip (ref);
   path rp= reverse (ip);
   path p = rp * root (mod);
@@ -440,6 +462,11 @@ remove_node (tree& ref, int pos) {
   apply (ref, mod_remove_node (path (), pos));
 }
 
+void
+set_cursor (tree& ref, int pos, tree data) {
+  apply (ref, mod_set_cursor (path (), pos, data));
+}
+
 void
 touch (tree& ref) {
   //cout << "Touch " << ref << "\n";
@@ -494,6 +521,14 @@ remove_node (path p) {
   remove_node (subtree (the_et, path_up (p)), last_item (p));
 }
 
+void
+set_cursor (path p, tree data) {
+  if (is_inside (the_et, p))
+    set_cursor (subtree (the_et, path_up (p)), last_item (p), data);
+  else
+    cout << "TeXmacs] warning: invalid cursor position " << p << "\n";
+}
+
 void
 touch (path p) {
   touch (subtree (the_et, p));
@@ -531,6 +566,9 @@ observer_rep::announce (tree& ref, modification mod) {
   case MOD_REMOVE_NODE:
     announce_remove_node (ref, mod->p);
     break;
+  case MOD_SET_CURSOR:
+    announce_set_cursor (ref, mod->p, mod->t);
+    break;
   }
 }
 
@@ -584,6 +622,11 @@ observer_rep::announce_remove_node (tree& ref, path p) {
   (void) ref; (void) p;
 }
 
+void
+observer_rep::announce_set_cursor (tree& ref, path p, tree data) {
+  (void) ref; (void) p; (void) data;
+}
+
 void
 observer_rep::notify_assign (tree& ref, tree t) {
   (void) ref; (void) t;
@@ -634,6 +677,11 @@ observer_rep::notify_remove_node (tree& ref, int pos) {
   (void) ref; (void) pos;
 }
 
+void
+observer_rep::notify_set_cursor (tree& ref, int pos, tree data) {
+  (void) ref; (void) pos; (void) data;
+}
+
 void
 observer_rep::notify_detach (tree& ref, tree closest, bool right) {
   (void) ref; (void) closest; (void) right;
@@ -682,7 +730,7 @@ observer_rep::get_tree (tree& t) {
 
 bool
 observer_rep::set_highlight (int lan, int col, int start, int end) {
-  (void) col; (void) start; (void) end;
+  (void) col; (void) start; (void) end; (void) lan;
   return false;
 }
 
