@@ -53,6 +53,7 @@ public:
   virtual void announce_assign_node (tree& ref, path p, tree_label op);
   virtual void announce_insert_node (tree& ref, path p, tree ins);
   virtual void announce_remove_node (tree& ref, path p);
+  virtual void announce_set_cursor  (tree& ref, path p, tree data);
   virtual void done                 (tree& ref, modification mod);
   virtual void touched              (tree& ref, path p);
 
@@ -67,6 +68,7 @@ public:
   virtual void notify_assign_node   (tree& ref, tree_label op);
   virtual void notify_insert_node   (tree& ref, int pos);
   virtual void notify_remove_node   (tree& ref, int pos);
+  virtual void notify_set_cursor    (tree& ref, int pos, tree data);
   virtual void notify_detach        (tree& ref, tree closest, bool right);
 
   // Extra routines for particular types of observers
@@ -122,6 +124,7 @@ void join        (tree& ref, int pos);
 void assign_node (tree& ref, tree_label op);
 void insert_node (tree& ref, int pos, tree t);
 void remove_node (tree& ref, int pos);
+void set_cursor  (tree& ref, int pos, tree data);
 void touch       (tree& ref);
 
 void assign      (path p, tree t);
@@ -132,6 +135,7 @@ void join        (path p);
 void assign_node (path p, tree_label op);
 void insert_node (path p, tree ins);
 void remove_node (path p);
+void set_cursor  (path p, tree data);
 void touch       (path p);
 
 void insert_observer (observer& o, observer what);
@@ -151,6 +155,9 @@ void tree_pointer_delete (observer o);
 
 path obtain_position (observer o);
 
+observer search_observer (tree& ref, int type);
+bool admits_edit_observer (tree t);
+
 void attach_highlight (tree& ref, int lan);
 void attach_highlight (tree& ref, int lan, int col, int start, int end);
 bool has_highlight (tree& ref, int lan);
