@@ -13,7 +13,7 @@
 #include "X11/x_window.hpp"
 #include "iterator.hpp"
 #include "converter.hpp"
-#include "socket_server.hpp"
+#include "tm_link.hpp"
 #include "message.hpp"
 
 #ifdef OS_WIN32
@@ -26,14 +26,14 @@
 #include <unistd.h>
 #endif
 
-
 #if defined(X11TEXMACS) && defined(MACOSX_EXTENSIONS)
 #include "MacOS/mac_app.h"
 #endif
 
-
 extern hashmap<Window,pointer> Window_to_window;
 int  nr_windows= 0;
+int  alt_mask= 0;
+int  meta_mask= 0;
 
 static int  kbd_count= 0;
 static bool request_partial_redraw= false;
@@ -86,17 +86,14 @@ x_gui_rep::look_up_key (XKeyEvent* ev) {
     if (contains_unicode_char (r)) return r;
   }
   else XLookupString (ev, NULL, 0, &key, NULL);
-  string s= ((ev->state&3)? upper_key [key]: lower_key [key]);
+  string s= ((ev->state&1)? upper_key [key]: lower_key [key]);
   if ((N(s)>=2) && (s[0]=='K') && (s[1]=='-')) s= s (2, N(s));
 
   /* other keyboard modifiers */
   if (N(s)==0) return s;
-  if (ev->state&4) s= "C-" * s;
-  if (ev->state&8) s= "Mod1-" * s;
-  if (ev->state&16) s= "Mod2-" * s;
-  if (ev->state&32) s= "Mod3-" * s;
-  if (ev->state&64) s= "Mod4-" * s;
-  if (ev->state&128) s= "Mod5-" * s;
+  if (ev->state & 4) s= "C-" * s;
+  if (ev->state & alt_mask) s= "A-" * s;
+  if (ev->state & meta_mask) s= "M-" * s;
   // cout << "key press: " << s << LF;
   return s;
 }
@@ -375,6 +372,7 @@ x_gui_rep::event_loop () {
 	  report.type == NoExpose) continue;
 
     // Wait for events on all channels and interpose
+    //time_t t1= texmacs_time ();
     if (wait) {
       struct timeval tv;
       tv.tv_sec  = delay/1000;
@@ -386,6 +384,8 @@ x_gui_rep::event_loop () {
     else wait= true;
     if (the_interpose_handler != NULL) the_interpose_handler ();
     if (nr_windows == 0) continue;
+    //time_t t2= texmacs_time ();
+    //if (t2 - t1 >= 10) cout << "interpose took " << t2-t1 << "ms\n";
 
     // Popup help balloons
     if (!is_nil (balloon_wid))
@@ -394,6 +394,7 @@ x_gui_rep::event_loop () {
 	  map_balloon ();
 
     // Redraw invalid windows
+    //time_t t3= texmacs_time ();
     if (XPending (dpy) == 0 || request_partial_redraw) {
       interrupted= false;
       interrupt_time= texmacs_time () + (100 / (XPending (dpy) + 1));
@@ -408,6 +409,8 @@ x_gui_rep::event_loop () {
 	if (!win->has_focus) win->repaint_invalid_regions();
       }
     }
+    //time_t t4= texmacs_time ();
+    //if (t4 - t3 >= 10) cout << "redraw took " << t4-t3 << "ms\n";
 
     // Handle alarm messages
     if (!is_nil (messages)) {
