@@ -65,6 +65,8 @@
 #include "file.hpp"
 #include "analyze.hpp"
 
+#include <ctype.h>
+
 #if defined(OS_WIN32)  || defined(__MINGW32__)
 #define WINPATHS
 #endif
@@ -316,6 +318,10 @@ operator * (url u1, url u2) {
     if (is_semi_root (u1))
       return u1 * u2[2];
   }
+  if (is_concat (u2) && (u2[1] == url_ancestor ())) {
+    if (is_root (u1) || is_semi_root (u1)) return u1 * u2[2];
+    return (u1 * u2[2]) | ((u1 * url_parent ()) * u2);
+  }
   if (is_concat (u1)) return u1[1] * (u1[2] * u2);
   return as_url (tuple ("concat", u1->t, u2->t));
 }
@@ -479,8 +485,8 @@ as_string (url u, int type) {
   return "";
 }
 
-ostream&
-operator << (ostream& out, url u) {
+tm_ostream&
+operator << (tm_ostream& out, url u) {
   return out << as_string (u, URL_SYSTEM);
 }
 
@@ -514,7 +520,7 @@ suffix (url u) {
     if (s[i]=='.') break;
   if ((i>0) && (i<n-1)) {
     string r= s (i+1, n);
-    while ((N(r)>0) && (r[N(r)-1]=='~')) r= r(0, N(r)-1);
+    while ((N(r)>0) && (r[N(r)-1]=='~' || r[N(r)-1]=='#')) r= r(0, N(r)-1);
     return r;
   }
   return "";
@@ -811,7 +817,11 @@ exists (url u) {
 
 bool
 exists_in_path (url u) {
+#if defined (OS_WIN32) || defined (__MINGW__) || defined (__MINGW32__)
+  return !is_none (resolve_in_path (url (as_string (u) * ".exe")));
+#else
   return !is_none (resolve_in_path (u));
+#endif
 }
 
 bool
