@@ -234,7 +234,7 @@ image_size (url image, int& w, int& h) {
   }
 #endif
 #ifdef MACOSX_EXTENSIONS 
-  if ( mac_image_size (image, w, h) ) {
+  if (mac_image_size (image, w, h) ) {
     //cout << "mac " << image << "\n";
     return;
   }
@@ -315,8 +315,11 @@ image_to_png (url image, url png, int w, int h) {
   }*/
 #ifdef MACOSX_EXTENSIONS
   //cout << "mac convert " << image << ", " << png << "\n";
-  mac_image_to_png (image, png, w, h);
-#else
+  if (mac_supports (image)) {
+    mac_image_to_png (image, png, w, h);
+    return;
+  }
+#endif
 #ifdef QTTEXMACS
   if (qt_supports (image)) {
     //cout << "qt convert " << image << ", " << png << "\n";
@@ -335,6 +338,5 @@ image_to_png (url image, url png, int w, int h) {
   string cmd= "convert";
   if (w > 0 && h > 0) cmd << " -resize " * as_string(w) * "x" * as_string(h) * "!";
   system (cmd, image, png);
-#endif
 }
 
