@@ -292,6 +292,22 @@ tm_new (const A1& a1, const A2& a2, const A3& a3,
   return (C*) ptr;
 }
 
+template<typename C, typename A1, typename A2, typename A3,
+	 typename A4, typename A5, typename A6,
+	 typename A7, typename A8, typename A9,
+	 typename A10, typename A11, typename A12,
+	 typename A13, typename A14, typename A15> inline C*
+tm_new (const A1& a1, const A2& a2, const A3& a3,
+	const A4& a4, const A5& a5, const A6& a6,
+	const A7& a7, const A8& a8, const A9& a9,
+	const A10& a10, const A11& a11, const A12& a12,
+	const A13& a13, const A14& a14, const A15& a15) {
+  void* ptr= fast_new (sizeof (C));
+  (void) new (ptr) C (a1, a2, a3, a4, a5, a6, a7, a8, a9, a10,
+		      a11, a12, a13, a14, a15);
+  return (C*) ptr;
+}
+
 template<typename C> inline void
 tm_delete (C* ptr) {
   ptr -> ~C ();
@@ -523,6 +539,20 @@ tm_new (const A1& a1, const A2& a2, const A3& a3,
   return new C (a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12, a13, a14);
 }
 
+template<typename C, typename A1, typename A2, typename A3,
+	 typename A4, typename A5, typename A6,
+	 typename A7, typename A8, typename A9,
+	 typename A10, typename A11, typename A12,
+	 typename A13, typename A14, typename A15> inline C*
+tm_new (const A1& a1, const A2& a2, const A3& a3,
+	const A4& a4, const A5& a5, const A6& a6,
+	const A7& a7, const A8& a8, const A9& a9,
+	const A10& a10, const A11& a11, const A12& a12,
+	const A13& a13, const A14& a14, const A15& a15) {
+  return new C (a1, a2, a3, a4, a5, a6, a7, a8, a9,
+                a10, a11, a12, a13, a14, a15);
+}
+
 template<typename C> inline void
 tm_delete (C* ptr) {
   delete ptr;
