@@ -59,7 +59,6 @@ concater_rep::typeset_bigop (tree t, path ip) {
     bool flag= (!env->math_condensed) && (l != ".");
     box b= big_operator_box (ip, s, env->fn, env->col,
 			     env->display_style? 2: 1);
-    if (flag) print (space (spc->min>>1, spc->def>>1, spc->max));
     print (STD_ITEM, OP_BIG, b);
     penalty_min (HYPH_PANIC);
     if ((l != "int") && (l != "oint")) with_limits (LIMITS_DISPLAY);
@@ -238,13 +237,13 @@ concater_rep::typeset_wide (tree t, path ip, bool above) {
     wide= true;
   }
   else {
-    wide= (b->w() >= (env->fn->wfn));
+    wide= (b->w() >= (env->fn->wfn)) || is_func (t, VAR_WIDE);
     if (ends (s, "dot>") || (s == "<acute>") ||
         (s == "<grave>") || (s == "<abovering>"))
       wide= false;
   }
   if (wide) {
-    SI w  = env->fn->wline;
+    SI w = env->fn->wline;
     box wideb;
     if ((s == "^") || (s == "<hat>"))
       wideb= wide_hat_box   (decorate_middle (ip), b->x1, b->x2, w, env->col);
