@@ -56,11 +56,13 @@ concater_rep::typeset_colored_substring
   case SPC_TINY: \
     print (space (spc->min>>2, spc->def>>2, spc->max>>2)); \
     break; \
+  case SPC_HALF: \
+    print (space (spc->min>>1, spc->def>>2, spc->max>>1)); \
+    break; \
   case SPC_OPERATOR: \
     print (space (spc->min>>1, spc->def>>1, spc->max)); \
     break; \
   case SPC_BIGOP: \
-    print (spc); \
     break; \
   }
 
@@ -77,6 +79,9 @@ concater_rep::typeset_colored_substring
   case SPC_TINY: \
     print (space (spc->min>>4, spc->def>>4, spc->max>>4)); \
     break; \
+  case SPC_HALF: \
+    print (space (spc->min>>3, spc->def>>4, spc->max>>3)); \
+    break; \
   case SPC_OPERATOR: \
     print (space (spc->min>>3, spc->def>>3, spc->max>>2)); \
     break; \
@@ -96,8 +101,8 @@ concater_rep::typeset_text_string (tree t, path ip, int pos, int end) {
     start= pos;
     text_property tp= env->lan->advance (t, pos);
     if (pos > end) pos= end;
-    if ((pos>start) && (s[start]==' ')) { // spaces
-      if (start==0) typeset_substring ("", ip, 0);
+    if ((pos > start) && (s[start] == ' ')) { // spaces
+      if (start == 0) typeset_substring ("", ip, 0);
       penalty_min (tp->pen_after);
       PRINT_SPACE (tp->spc_before);
       PRINT_SPACE (tp->spc_after);
@@ -129,12 +134,16 @@ concater_rep::typeset_math_string (tree t, path ip, int pos, int end) {
     while (k > 0 && a[k-1]->op_type == OP_SKIP) k--;
     int prev_op_type= (k == 0? OP_TEXT: a[k-1]->op_type);
     int succ_status= succession_status (prev_op_type, tp->op_type);
+    //cout << "Succession [" << s (start, pos) << "] "
+    //     << "(" << prev_op_type << ", " << tp->op_type << ")"
+    //     << " -> " << succ_status << "\n";
     if ((succ_status & 1) != 0 && k > 0) a[k-1]->spc= space (0);
     bool spc_ok= (succ_status <= 1);
     if (pos > end) pos= end;
-    if ((pos>start) && (s[start]==' ')) { // spaces
-      if (start==0) typeset_substring ("", ip, 0);
-      penalty_min (tp->pen_after);
+    if ((pos > start) && (s[start]==' ')) { // spaces
+      if (start == 0) typeset_substring ("", ip, 0);
+      penalty_max (HYPH_INVALID);
+      //penalty_min (tp->pen_after);
       if (spc_ok) {
         PRINT_SPACE (tp->spc_before);
         PRINT_SPACE (tp->spc_after);
@@ -148,6 +157,14 @@ concater_rep::typeset_math_string (tree t, path ip, int pos, int end) {
         if (condensed) PRINT_CONDENSED_SPACE (tp->spc_before)
         else PRINT_SPACE (tp->spc_before)
       }
+      if (pos > start && s[start] == '*' && env->info_level >= INFO_SHORT) {
+        color c = rgb_color (160, 160, 255);
+        box   tb= text_box (decorate (ip), 0, "<cdot>", env->fn, c);
+        box   sb= specific_box (decorate (ip), tb, false, env->fn);
+        box   mb= move_box (decorate (ip), sb, -tb->w()>>1, 0);
+        box   rb= resize_box (decorate (ip), mb, 0, tb->y1, 0, tb->y2);
+        a << line_item (STD_ITEM, OP_SKIP, rb, HYPH_INVALID);
+      }
       typeset_math_substring (s (start, pos), ip, start, tp->op_type);
       penalty_min (tp->pen_after);
       if (tp->limits != LIMITS_NONE) with_limits (tp->limits);
@@ -171,7 +188,7 @@ concater_rep::typeset_prog_string (tree t, path ip, int pos, int end) {
     text_property tp= env->lan->advance (t, pos);
     if (pos > end) pos= end;
     if ((pos>start) && (s[start]==' ')) { // spaces
-      if (start==0) typeset_substring ("", ip, 0);
+      if (start == 0) typeset_substring ("", ip, 0);
       penalty_min (tp->pen_after);
       PRINT_SPACE (tp->spc_before);
       PRINT_SPACE (tp->spc_after);
@@ -380,19 +397,38 @@ concater_rep::typeset_repeat (tree t, path ip) {
 void
 concater_rep::typeset_formatting (tree t, path ip, string v) {
   if (N(t) == 0) { typeset_error (t, ip); return; }
-  int n= N(t);
-  tree new_format= env->read (v) * t (0, n-1);
-  tree old_format= env->local_begin (v, new_format);
-  if (v != CELL_FORMAT) {
+  if (rigid && v == ATOM_DECORATIONS) {
+    int k, n=N(t);
+    box b= typeset_as_concat (env, t[n-1], descend (ip, n-1));
+    tree e (DBOX);
+    for (k=n-2; k>=0; k--)
+      if (is_func (t[k], MACRO, 2))
+        e= tree (COMPOUND, t[k], e);
+    if (e != tree (DBOX)) {
+      env->decorated_boxes << b;
+      box bb= typeset_as_concat (env, attach_middle (e, ip));
+      env->decorated_boxes->resize (N (env->decorated_boxes) - 1);
+      b= bb;
+    }
     marker (descend (ip, 0));
-    control (t (0, N(t)-1), decorate (ip));
-  }
-  typeset (t[n-1], descend (ip, n-1));
-  if (v != CELL_FORMAT) {
-    control (tree (L(t)), decorate (ip));
+    print (b);
     marker (descend (ip, 1));
   }
-  env->local_end (v, old_format);
+  else {
+    int n= N(t);
+    tree new_format= env->read (v) * t (0, n-1);
+    tree old_format= env->local_begin (v, new_format);
+    if (v != CELL_FORMAT) {
+      marker (descend (ip, 0));
+      control (t (0, N(t)-1), decorate (ip));
+    }
+    typeset (t[n-1], descend (ip, n-1));
+    if (v != CELL_FORMAT) {
+      control (tree (L(t)), decorate (ip));
+      marker (descend (ip, 1));
+    }
+    env->local_end (v, old_format);
+  }
 }
 
 void
