@@ -82,24 +82,24 @@ void
 concater_rep::flag_ok (string s, path ip, color col) {
   path dip = decorate_right (ip);
   SI h= 4*env->fn->wfn/5;
-  int r, g, b;
-  get_rgb_color (col, r, g, b);
+  int r, g, b, a;
+  get_rgb_color (col, r, g, b, a);
   r= 255- (255 - r)/6;
   g= 255- (255 - g)/6;
   b= 255- (255 - b)/6;
-  color light= rgb_color (r, g, b);
-  string info_flag= env->get_string (INFO_FLAG);
-  if (info_flag == "short") {
+  color light= rgb_color (r, g, b, a);
+  int info= env->info_level;
+  if (info == INFO_MINIMAL || info == INFO_SHORT) {
     box infob= info_box (dip, h, env->fn->wline, col, light);
     box specb= specific_box (ip, infob, false, env->fn);
     print (specb);
   }
-  if (info_flag == "detailed" || info_flag == "paper") {
+  else if (info == INFO_DETAILED || info == INFO_PAPER) {
     int sz= script (env->fn_size, env->index_level+2);
     font gfn (tex_font ("ecrm", sz, (int) (env->magn*env->dpi)));
     box textb= text_box (decorate (ip), 0, s, gfn, col);
     box flagb= flag_box (dip, textb, h, env->fn->wline, col, light);
-    if (info_flag == "detailed") {
+    if (info == INFO_DETAILED) {
       box specb= specific_box (ip, flagb, false, env->fn);
       print (specb);
     }
@@ -729,7 +729,8 @@ concater_rep::typeset (tree t, path ip) {
 * User interface
 ******************************************************************************/
 
-concater_rep::concater_rep (edit_env env2): env (env2) {}
+concater_rep::concater_rep (edit_env env2, bool rigid2):
+  env (env2), rigid (rigid2) {}
 
 array<line_item>
 typeset_concat (edit_env env, tree t, path ip) {
@@ -752,7 +753,7 @@ typeset_marker (edit_env env, path ip) {
 
 box
 typeset_as_concat (edit_env env, tree t, path ip) {
-  concater ccc= tm_new<concater_rep> (env);
+  concater ccc= tm_new<concater_rep> (env, true);
   ccc->typeset (t, ip);
   ccc->finish ();
   array<line_item> a= ccc->a;
