@@ -1119,6 +1119,13 @@ edit_env_rep::exec_divide (tree t) {
     if (den == 0) return tree (ERROR, "division by zero");
     return as_string (as_int (t1->label) / den);
   }
+  if (is_double (t1->label) && (is_double (t2->label))) {
+    double den= as_double (t2->label);
+    if (den == 0) return tree (ERROR, "division by zero");
+    return as_string (floor (as_double (t1->label) / den));
+  }
+  if (is_anylen (t1->label) && (is_anylen (t2->label)))
+    return as_string (tmlen_div (as_tmlen (t1), as_tmlen (t2)));
   return tree (ERROR, "bad divide");
 }
 
@@ -1134,6 +1141,15 @@ edit_env_rep::exec_modulo (tree t) {
     if (den == 0) return tree (ERROR, "modulo zero");
     return as_string (as_int (t1->label) % den);
   }
+  if (is_double (t1->label) && (is_double (t2->label))) {
+    double num= as_double (t1->label);
+    double den= as_double (t2->label);
+    if (den == 0) return tree (ERROR, "modulo zero");
+    double div= floor (num / den);
+    return as_string (num - div * den);
+  }
+  if (is_anylen (t1->label) && (is_anylen (t2->label)))
+    return tmlen_mod (as_tmlen (t1), as_tmlen (t2));
   return tree (ERROR, "bad modulo");
 }
 
@@ -1490,15 +1506,21 @@ edit_env_rep::exec_greatereq (tree t) {
 
 tree
 edit_env_rep::exec_hard_id (tree t) {
-  if (N(t) == 0) {
-    pointer ptr= (pointer) this;
+  pointer ptr= (pointer) this;
+  if (N(t) == 0)
     return "%" * as_hexadecimal (ptr);
-  }
   else {
     t= expand (t[0], true);
-    pointer ptr1= (pointer) this;
-    pointer ptr2= (pointer) t.operator -> ();
-    return "%" * as_hexadecimal (ptr1) * "-" * as_hexadecimal (ptr2);
+    pointer tptr= (pointer) t.operator -> ();
+    if (is_accessible (obtain_ip (t)))
+      return "%" * as_hexadecimal (ptr) *
+             "-" * as_hexadecimal (tptr);
+    else {
+      int h= hash (t);
+      return "%" * as_hexadecimal (ptr) *
+             "-" * as_hexadecimal (tptr) *
+             "-" * as_hexadecimal (h);
+    }
   }
 }
 
@@ -1569,7 +1591,7 @@ edit_env_rep::exec_set_binding (tree t) {
       }
     }
   }
-  return tree (HIDDEN, "", keys);
+  return tree (HIDDEN, keys);
 }
 
 tree
